@@ -270,7 +270,8 @@ xplr.config.general.table.col_spacing = 1
 xplr.config.general.table.col_widths = {
     { Percentage = 10 },
     { Percentage = 50 },
-    { Percentage = 20 },
+    { Percentage = 10 },
+    { Percentage = 10 },
     { Percentage = 20 },
 }
 
@@ -278,6 +279,7 @@ xplr.config.general.table.col_widths = {
 xplr.config.general.table.header.cols = {
     { format = " index", style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil } },
     { format = "╭──── path", style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil } },
+    { format = " permissions", style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil } },
     { format = "size", style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil } },
     { format = "type", style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil } },
 }
@@ -305,6 +307,10 @@ xplr.config.general.table.row.cols = {
         format = "builtin.fmt_general_table_row_cols_3",
         style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil }
     },
+    {
+        format = "builtin.fmt_general_table_row_cols_4",
+        style = { add_modifiers = nil, bg = nil, fg = nil, sub_modifiers = nil }
+    },
 }
 xplr.config.general.table.row.height = 0
 xplr.config.general.table.row.style.add_modifiers = nil
@@ -551,16 +557,6 @@ xplr.config.modes.builtin.default = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {
-      ["k"] = "up",
-      tab = "ctrl-i",
-      ["/"] = "ctrl-f",
-      ["V"] = "ctrl-a",
-      ["h"] = "left",
-      ["v"] = "space",
-      ["j"] = "down",
-      ["l"] = "right"
-    },
     on_key = {
       ["#"] = {
         help = nil,
@@ -601,7 +597,7 @@ xplr.config.modes.builtin.default = {
       },
       ["G"] = {
         help = "go to bottom",
-        messages = {"FocusLast"}
+        messages = {"PopMode", "FocusLast", "Refresh"}
       },
       ["ctrl-a"] = {
         help = "select/unselect all",
@@ -749,13 +745,21 @@ xplr.config.modes.builtin.default = {
   }
 }
 
+xplr.config.modes.builtin.default.key_bindings.on_key["tab"] = xplr.config.modes.builtin.default.key_bindings.on_key["ctrl-i"]
+xplr.config.modes.builtin.default.key_bindings.on_key["v"] = xplr.config.modes.builtin.default.key_bindings.on_key.space
+xplr.config.modes.builtin.default.key_bindings.on_key["V"] = xplr.config.modes.builtin.default.key_bindings.on_key["ctrl-a"]
+xplr.config.modes.builtin.default.key_bindings.on_key["/"] = xplr.config.modes.builtin.default.key_bindings.on_key["ctrl-f"]
+xplr.config.modes.builtin.default.key_bindings.on_key["h"] = xplr.config.modes.builtin.default.key_bindings.on_key.left
+xplr.config.modes.builtin.default.key_bindings.on_key["j"] = xplr.config.modes.builtin.default.key_bindings.on_key.down
+xplr.config.modes.builtin.default.key_bindings.on_key["k"] = xplr.config.modes.builtin.default.key_bindings.on_key.up
+xplr.config.modes.builtin.default.key_bindings.on_key["l"] = xplr.config.modes.builtin.default.key_bindings.on_key.right
+
 ------ Recover
 xplr.config.modes.builtin.recover = {
   name = "recover",
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["ctrl-c"] = {
         help = "terminate",
@@ -782,7 +786,6 @@ xplr.config.modes.builtin.selection_ops = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["c"] = {
         help = "copy here",
@@ -872,7 +875,6 @@ xplr.config.modes.builtin.create = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["ctrl-c"] = {
         help = "terminate",
@@ -920,7 +922,6 @@ xplr.config.modes.builtin.create_directory = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       backspace = {
         help = "remove last character",
@@ -983,7 +984,6 @@ xplr.config.modes.builtin.create_file = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       backspace = {
         help = "remove last character",
@@ -1046,10 +1046,6 @@ xplr.config.modes.builtin.number = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {
-      ["j"] = "down",
-      ["k"] = "up"
-    },
     on_key = {
       backspace = {
         help = "remove last character",
@@ -1098,13 +1094,15 @@ xplr.config.modes.builtin.number = {
   }
 }
 
+xplr.config.modes.builtin.number.key_bindings.on_key["j"] = xplr.config.modes.builtin.number.key_bindings.on_key.down
+xplr.config.modes.builtin.number.key_bindings.on_key["k"] = xplr.config.modes.builtin.number.key_bindings.on_key.up
+
 ------ Go to
 xplr.config.modes.builtin.go_to = {
   name = "go to",
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["ctrl-c"] = {
         help = "terminate",
@@ -1159,7 +1157,6 @@ xplr.config.modes.builtin.rename = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       backspace = {
         help = "remove last character",
@@ -1219,7 +1216,6 @@ xplr.config.modes.builtin.delete = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["D"] = {
         help = "force delete",
@@ -1291,7 +1287,6 @@ xplr.config.modes.builtin.action = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["!"] = {
         help = "shell",
@@ -1359,6 +1354,12 @@ xplr.config.modes.builtin.action = {
           },
           "Refresh"
         }
+      },
+      ["q"] = {
+        help = "quit",
+        messages = {
+          "Quit",
+        }
       }
     },
     on_alphabet = nil,
@@ -1383,11 +1384,6 @@ xplr.config.modes.builtin.search = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {
-      esc = "enter",
-      ["ctrl-n"] = "down",
-      ["ctrl-p"] = "up"
-    },
     on_key = {
       backspace = {
         help = "remove last character",
@@ -1503,15 +1499,16 @@ xplr.config.modes.builtin.search = {
   }
 }
 
+xplr.config.modes.builtin.search.key_bindings.on_key["esc"] = xplr.config.modes.builtin.search.key_bindings.on_key.enter
+xplr.config.modes.builtin.search.key_bindings.on_key["ctrl-n"] = xplr.config.modes.builtin.search.key_bindings.on_key.down
+xplr.config.modes.builtin.search.key_bindings.on_key["ctrl-p"] = xplr.config.modes.builtin.search.key_bindings.on_key.up
+
 ------ Filter
 xplr.config.modes.builtin.filter = {
   name = "filter",
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {
-      esc = "enter"
-    },
     on_key = {
       ["R"] = {
         help = "relative does not contain",
@@ -1571,13 +1568,14 @@ xplr.config.modes.builtin.filter = {
   }
 }
 
+xplr.config.modes.builtin.filter.key_bindings.on_key["esc"] = xplr.config.modes.builtin.filter.key_bindings.on_key.enter
+
 ------ Relative path does contain
 xplr.config.modes.builtin.relative_path_does_contain = {
   name = "relative path does contain",
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       backspace = {
         help = "remove last character",
@@ -1665,7 +1663,6 @@ xplr.config.modes.builtin.relative_path_does_not_contain = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       backspace = {
         help = "remove last character",
@@ -1752,9 +1749,6 @@ xplr.config.modes.builtin.sort = {
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {
-      esc = "enter"
-    },
     on_key = {
       ["!"] = {
         help = "reverse sorters",
@@ -1932,13 +1926,14 @@ xplr.config.modes.builtin.sort = {
   }
 }
 
+xplr.config.modes.builtin.sort.key_bindings.on_key["esc"] = xplr.config.modes.builtin.sort.key_bindings.on_key.enter
+
 ------ Switch layout
 xplr.config.modes.builtin.switch_layout = {
   name = "switch layout",
   help = nil,
   extra_help = nil,
   key_bindings = {
-    remaps = {},
     on_key = {
       ["1"] = {
         help = "default",
@@ -1999,9 +1994,9 @@ xplr.config.modes.builtin.switch_layout = {
 ---- Custom
 xplr.config.modes.custom = {}
 
-
 -- Function
 ---- Formaters
+------ Index
 xplr.fn.builtin.fmt_general_table_row_cols_0 = function(m)
   local r = ""
   if m.is_before_focus then
@@ -2015,11 +2010,12 @@ xplr.fn.builtin.fmt_general_table_row_cols_0 = function(m)
   return r
 end
 
+------ Path
 xplr.fn.builtin.fmt_general_table_row_cols_1 = function(m)
   local r = m.tree .. m.prefix
 
   if m.meta.icon == nil then
-    r = r .. " "
+    r = r .. ""
   else
     r = r .. m.meta.icon .. " "
   end
@@ -2044,13 +2040,101 @@ xplr.fn.builtin.fmt_general_table_row_cols_1 = function(m)
         r = r .. "/"
       end
     end
-
   end
 
   return r
 end
 
+------ Permissions
 xplr.fn.builtin.fmt_general_table_row_cols_2 = function(m)
+
+  local no_color = os.getenv("NO_COLOR")
+
+  local function green(x)
+    if no_color == nil then
+      return "\x1b[32m" .. x .. "\x1b[0m"
+    else
+      return x
+    end
+  end
+
+  local function yellow(x)
+    if no_color == nil then
+      return "\x1b[33m" .. x .. "\x1b[0m"
+    else
+      return x
+    end
+  end
+
+
+  local function red(x)
+    if no_color == nil then
+      return "\x1b[31m" .. x .. "\x1b[0m"
+    else
+      return x
+    end
+  end
+
+  local function bit(x, color, cond)
+    if cond then
+      return color(x)
+    else
+      return color("-")
+    end
+  end
+
+  local p = m.permissions
+
+  -- TODO: Track https://github.com/uttarayan21/ansi-to-tui/issues/3
+  local r = " "
+
+  -- User
+  r = r .. bit("r", green, p.user_read)
+  r = r .. bit("w", yellow, p.user_write)
+
+  if p.user_execute == false and p.setuid == false then
+    r = r .. bit("-", red, p.user_execute)
+  elseif p.user_execute == true and p.setuid == false then
+    r = r .. bit("x", red, p.user_execute)
+  elseif p.user_execute == false and p.setuid == true then
+    r = r .. bit("S", red, p.user_execute)
+  else
+    r = r .. bit("s", red, p.user_execute)
+  end
+
+  -- Group
+  r = r .. bit("r", green, p.group_read)
+  r = r .. bit("w", yellow, p.group_write)
+
+  if p.group_execute == false and p.setuid == false then
+    r = r .. bit("-", red, p.group_execute)
+  elseif p.group_execute == true and p.setuid == false then
+    r = r .. bit("x", red, p.group_execute)
+  elseif p.group_execute == false and p.setuid == true then
+    r = r .. bit("S", red, p.group_execute)
+  else
+    r = r .. bit("s", red, p.group_execute)
+  end
+
+  -- Other
+  r = r .. bit("r", green, p.other_read)
+  r = r .. bit("w", yellow, p.other_write)
+
+  if p.other_execute == false and p.setuid == false then
+    r = r .. bit("-", red, p.other_execute)
+  elseif p.other_execute == true and p.setuid == false then
+    r = r .. bit("x", red, p.other_execute)
+  elseif p.other_execute == false and p.setuid == true then
+    r = r .. bit("S", red, p.other_execute)
+  else
+    r = r .. bit("s", red, p.other_execute)
+  end
+
+  return r
+end
+
+------ Size
+xplr.fn.builtin.fmt_general_table_row_cols_3 = function(m)
   if not m.is_dir then
     return m.human_size
   else
@@ -2058,7 +2142,8 @@ xplr.fn.builtin.fmt_general_table_row_cols_2 = function(m)
   end
 end
 
-xplr.fn.builtin.fmt_general_table_row_cols_3 = function(m)
+------ Mime
+xplr.fn.builtin.fmt_general_table_row_cols_4 = function(m)
   if m.is_symlink and not m.is_broken then
     return m.symlink.mime_essence
   else
